@@ -1,10 +1,10 @@
 
-#include "libgeos.h"
-#include "geos-common.h"
 #include "Rinternals.h"
+#include "geos-common.h"
+#include "libgeos.h"
 
-SEXP geos_c_segment_intersection(SEXP Sax0, SEXP Say0, SEXP Sax1, SEXP Say1,
-                                 SEXP Sbx0, SEXP Sby0, SEXP Sbx1, SEXP Sby1) {
+SEXP geos_c_segment_intersection(SEXP Sax0, SEXP Say0, SEXP Sax1, SEXP Say1, SEXP Sbx0,
+                                 SEXP Sby0, SEXP Sbx1, SEXP Sby1) {
   R_xlen_t size = Rf_xlength(Sax0);
   SEXP resultX = PROTECT(Rf_allocVector(REALSXP, size));
   SEXP resultY = PROTECT(Rf_allocVector(REALSXP, size));
@@ -24,19 +24,11 @@ SEXP geos_c_segment_intersection(SEXP Sax0, SEXP Say0, SEXP Sax1, SEXP Say1,
   double* cy = REAL(resultY);
 
   for (R_xlen_t i = 0; i < size; i++) {
-    if (R_FINITE(ax0[i]) && R_FINITE(ay0[i]) &&
-        R_FINITE(ax1[i]) && R_FINITE(ay1[i]) &&
-        R_FINITE(bx0[i]) && R_FINITE(by0[i]) &&
-        R_FINITE(bx1[i]) && R_FINITE(by1[i])) {
-
-      resultCode = GEOSSegmentIntersection_r(
-        handle,
-        ax0[i], ay0[i],
-        ax1[i], ay1[i],
-        bx0[i], by0[i],
-        bx1[i], by1[i],
-        &cx[i], &cy[i]
-      );
+    if (R_FINITE(ax0[i]) && R_FINITE(ay0[i]) && R_FINITE(ax1[i]) && R_FINITE(ay1[i]) &&
+        R_FINITE(bx0[i]) && R_FINITE(by0[i]) && R_FINITE(bx1[i]) && R_FINITE(by1[i])) {
+      resultCode =
+          GEOSSegmentIntersection_r(handle, ax0[i], ay0[i], ax1[i], ay1[i], bx0[i],
+                                    by0[i], bx1[i], by1[i], &cx[i], &cy[i]);
 
       // returns 0 on error, -1 if segments do not intersect
       if (resultCode == 1) {
@@ -47,8 +39,8 @@ SEXP geos_c_segment_intersection(SEXP Sax0, SEXP Say0, SEXP Sax1, SEXP Say1,
         REAL(resultY)[i] = NAN;
       } else {
         // this would fire if any value were NaN, which we have checked above
-        UNPROTECT(2); // # nocov
-        GEOS_ERROR("Can't compute segment intersection [i=%d]", i + 1); // # nocov
+        UNPROTECT(2);                                                           // # nocov
+        GEOS_ERROR("Can't compute segment intersection [i=%ld]", (long)i + 1);  // # nocov
       }
 
     } else {
@@ -57,16 +49,16 @@ SEXP geos_c_segment_intersection(SEXP Sax0, SEXP Say0, SEXP Sax1, SEXP Say1,
     }
   }
 
-  
   const char* names[] = {"x", "y", ""};
   SEXP result = PROTECT(Rf_mkNamed(VECSXP, names));
   SET_VECTOR_ELT(result, 0, resultX);
   SET_VECTOR_ELT(result, 1, resultY);
-  UNPROTECT(3); // resultX, resultY, result
+  UNPROTECT(3);  // resultX, resultY, result
   return result;
 }
 
-SEXP geos_c_orientation_index(SEXP SAx, SEXP SAy, SEXP SBx, SEXP SBy, SEXP SPx, SEXP SPy) {
+SEXP geos_c_orientation_index(SEXP SAx, SEXP SAy, SEXP SBx, SEXP SBy, SEXP SPx,
+                              SEXP SPy) {
   R_xlen_t size = Rf_xlength(SAx);
   SEXP result = PROTECT(Rf_allocVector(INTSXP, size));
 
@@ -83,17 +75,14 @@ SEXP geos_c_orientation_index(SEXP SAx, SEXP SAy, SEXP SBx, SEXP SBy, SEXP SPx,
   for (R_xlen_t i = 0; i < size; i++) {
     if (R_FINITE(Ax[i]) && R_FINITE(Ay[i]) && R_FINITE(Bx[i]) && R_FINITE(By[i]) &&
         R_FINITE(Px[i]) && R_FINITE(Py[i])) {
-      resultCode = GEOSOrientationIndex_r(
-        handle,
-        Ax[i], Ay[i], Bx[i], By[i],
-        Px[i], Py[i]
-      );
+      resultCode =
+          GEOSOrientationIndex_r(handle, Ax[i], Ay[i], Bx[i], By[i], Px[i], Py[i]);
 
       // returns 2 on error
       if (resultCode == 2) {
         // this would fire if any value were NaN, which we have checked above
-        UNPROTECT(1); // # nocov
-        GEOS_ERROR("Can't compute orientation index [i=%d]", i + 1); // # nocov
+        UNPROTECT(1);                                                        // # nocov
+        GEOS_ERROR("Can't compute orientation index [i=%ld]", (long)i + 1);  // # nocov
       }
 
       INTEGER(result)[i] = resultCode;
@@ -102,6 +91,6 @@ SEXP geos_c_orientation_index(SEXP SAx, SEXP SAy, SEXP SBx, SEXP SBy, SEXP SPx,
     }
   }
 
-    UNPROTECT(1);
+  UNPROTECT(1);
   return result;
 }
