@@ -153,6 +153,125 @@ test_that("transformers work", {
   )
 })
 
+test_that("geos_line_merge/_directed() works ", {
+  expect_identical(
+    geos_write_wkt(geos_line_merge("MULTILINESTRING ((0 1, 2 3), (4 5, 2 3))")),
+    "LINESTRING (0 1, 2 3, 4 5)"
+  )
+
+  skip_if_not(geos_version() >= "3.11.0")
+
+  expect_identical(
+    geos_write_wkt(geos_line_merge_directed("MULTILINESTRING ((0 1, 2 3), (4 5, 2 3))")),
+    "MULTILINESTRING ((0 1, 2 3), (4 5, 2 3))"
+  )
+
+  expect_identical(
+    geos_write_wkt(geos_line_merge("MULTILINESTRING ((0 1, 2 3), (2 3, 4 5))")),
+    "LINESTRING (0 1, 2 3, 4 5)"
+  )
+})
+
+test_that("geos_concave_hull() works", {
+  skip_if_not(geos_version() >= "3.11.0")
+
+  expect_identical(
+    geos_write_wkt(
+      geos_concave_hull(
+        c(rep("MULTIPOINT (0 0, 1 0, 0 2, 0.5 0.5)", 2), NA),
+        c(1, 0, 1)
+      )
+    ),
+    c(
+      "POLYGON ((0 0, 0 2, 1 0, 0 0))",
+      "POLYGON ((0 0, 0 2, 0.5 0.5, 1 0, 0 0))",
+      NA
+    )
+  )
+})
+
+test_that("geos_concave_hull_of_polygons() works", {
+  skip_if_not(geos_version() >= "3.11.0")
+
+  geom_text <- "MULTIPOLYGON (((40 40, 20 45, 45 30, 40 40)),
+    ((20 35, 10 30, 10 10, 30 5, 45 20, 20 35))
+  )"
+
+  expect_identical(
+    geos_area(
+      geos_concave_hull_of_polygons(
+        c(rep(geom_text, 2), NA),
+        c(1, 0, 1)
+      )
+    ),
+    c(
+      geos_area(geos_convex_hull(geom_text)),
+      geos_area(geom_text),
+      NA
+    )
+  )
+})
+
+test_that("geos_polygon_hull_simplify() works", {
+  skip_if_not(geos_version() >= "3.11.0")
+
+  geom_text <- "MULTIPOLYGON (((40 40, 20 45, 45 30, 40 40)),
+    ((20 35, 10 30, 10 10, 30 5, 45 20, 20 35))
+  )"
+
+  expect_true(
+    geos_equals(
+      geom_text,
+      geos_polygon_hull_simplify(geom_text, 1, hull_type = "outer")
+    )
+  )
+
+  expect_true(
+    geos_contains(
+      geom_text,
+      geos_polygon_hull_simplify(geom_text, 0, hull_type = "inner")
+    )
+  )
+
+  expect_true(
+    geos_equals(
+      geom_text,
+      geos_polygon_hull_simplify(
+        geom_text,
+        1,
+        hull_type = "outer",
+        ratio_mode = "area"
+      )
+    )
+  )
+
+  expect_true(
+    geos_contains(
+      geom_text,
+      geos_polygon_hull_simplify(
+        geom_text,
+        1,
+        hull_type = "inner",
+        ratio_mode = "area"
+      )
+    )
+  )
+})
+
+test_that("geos_transform_xy() works", {
+  skip_if_not(geos_version() >= "3.11.0")
+
+  expect_identical(
+    geos_write_wkt(
+      geos_transform_xy(
+        c(NA, "POINT (0 1)"),
+        wk::wk_affine_translate(12, 34)
+      )
+    ),
+    c(NA, "POINT (12 35)")
+  )
+})
+
 test_that("geos_make_valid() works with params", {
   skip_if_not(geos_version() >= "3.10.0")
 
@@ -196,6 +315,18 @@ test_that("geos_envelope_rct() works", {
   )
 })
 
+test_that("geos_extent() works", {
+  expect_identical(
+    geos_extent(c("LINESTRING (0 0, 1 2)", "LINESTRING EMPTY", NA)),
+    data.frame(
+      xmin = c(0, Inf, NA),
+      ymin = c(0, Inf, NA),
+      xmax = c(1, -Inf, NA),
+      ymax = c(2, -Inf, NA)
+    )
+  )
+})
+
 test_that("geos_unary_union_prec() works", {
   if ((geos_version(runtime = TRUE) >= "3.9.1") && (geos_version(runtime = FALSE) >= "3.9.1")) {
     expect_identical(
@@ -333,6 +464,20 @@ test_that("densification works", {
   )
 })
 
+test_that("geos_remove_repeated_points() works", {
+  skip_if_not(geos_version() >= "3.11.0")
+
+  expect_identical(
+    geos_write_wkt(
+      geos_remove_repeated_points(
+        "LINESTRING (0 1, 2 3, 2.1 3)",
+        0.2
+      )
+    ),
+    "LINESTRING (0 1, 2.1 3)"
+  )
+})
+
 test_that("set precision works", {
   expect_identical(
     geos_equals(
@@ -463,6 +608,9 @@ test_that("geos_offset_curve works", {
 })
 
 test_that("geos_buffer errors with bad params", {
+  # geos leaks memory here
+  skip_if_not(identical(Sys.getenv("R_GEOS_TEST_WITH_KNOWN_LEAKS"), "true"))
+
   expect_error(geos_buffer("POINT (0 0)", 1, params = NULL), "must be created using")
 
   good_params <- geos_buffer_params()
@@ -501,9 +649,11 @@ test_that("triangulation works", {
 })
 
 test_that("voronoi diagrams work", {
-  expect_true(
-    geos_equals(
-      geos_voronoi_polygons("MULTIPOINT (0 0, 1 0, 0 3)"),
+  # GEOS seems to have trouble comparing these via geos_equals on
+  # some M1Mac builds.
+  expect_identical(
+    wk::wk_bbox(geos_voronoi_polygons("MULTIPOINT (0 0, 1 0, 0 3)")),
+    wk::wk_bbox(
       geos_voronoi_polygons(
         "MULTIPOINT (0 0, 1 0, 0 3)",
         # this is the default env
